==> haskell-yesod-default-1.2.0-197-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-ForPzJQxWaf4p6rT23aqS2
key: yesod-default-1.2.0-ForPzJQxWaf4p6rT23aqS2
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
author: Patrick Brisbin
exposed: True
indefinite: False
exposed-modules:
    Yesod.Default.Ignore
abi: eca79381090ee8c749c46b61af9215fe
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-ForPzJQxWaf4p6rT23aqS2
depends:
    base-4.10.0.0 yesod-core-1.4.37-IhqUI9QzPQ77Qqbq9ysylY
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             yesod-core-1.4.37-IhqUI9QzPQ77Qqbq9ysylY=225bd3d3bf1b6f44c066e4dbef19d5d8
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yesod-default-1.2.0-198-i686.pkg.tar.xz: usr/share/haskell/register/haskell-yesod-default.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/sbin:/usr/bin:/sbin:/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: yesod-default
version: 1.2.0
id: yesod-default-1.2.0-3Wmf2ZduzPRHrvh6S3fvta
key: yesod-default-1.2.0-3Wmf2ZduzPRHrvh6S3fvta
license: MIT
maintainer: Patrick Brisbin <pbrisbin@gmail.com>
stability: Stable
homepage: http://www.yesodweb.com/
synopsis: Default config and main functions for your yesod application (deprecated)
description:
    Since version 1.2 of Yesod, this functionality is provided by the yesod package. This package is no longer needed.
    execution of your yesod application
category: Web, Yesod
author: Patrick Brisbin
exposed: True
indefinite: False
exposed-modules:
    Yesod.Default.Ignore
abi: fcb92611b3af53b0530d774da5c2a605
trusted: False
import-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-default-1.2.0
library-dirs: /usr/lib/ghc-8.2.1/site-local/yesod-default-1.2.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/i386-linux-ghc-8.2.1/yesod-default-1.2.0
hs-libraries: HSyesod-default-1.2.0-3Wmf2ZduzPRHrvh6S3fvta
depends:
    base-4.10.0.0 yesod-core-1.4.37-H3gq1KrLSiCD4BHWdk8Tpz
abi-depends: base-4.10.0.0=a43b4ec12ad02cbfcdfe91f0942afb0a
             yesod-core-1.4.37-H3gq1KrLSiCD4BHWdk8Tpz=68dc02a30fc90d5d620eb669d64ba421
haddock-interfaces: /usr/share/doc/haskell-yesod-default/html/yesod-default.haddock
haddock-html: /usr/share/doc/haskell-yesod-default/html
' | '/usr/sbin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
